@@ -50,7 +50,10 @@ class KssView(Implicit, PloneKSSView):
         if item_uid:
             item = rc.lookupObject(item_uid)
             # The item must be in the container
-            assert item.aq_parent == container
+            # xxx: take away assertion since it causes problems
+            # in cases where the container may be wrong. This happens
+            # where viewlets are link providers.
+            # assert item.aq_parent == container
 
         # No item_uid supplied. This is a new item.
         if item is None:        
